OptimizationFunctions
=====================

.. toctree::
   :maxdepth: 3

.. automodule:: psyneulink.core.components.functions.optimizationfunctions
   :members:  OptimizationFunction, GradientOptimization, GridSearch, GaussianProcess, SampleSpec, SampleIterator
   :private-members:
   :exclude-members: Parameters


